@@ -4,7 +4,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
+# the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 
 import xml.etree.ElementTree as ET
@@ -137,7 +137,7 @@ def ts2policy(policyFile, tsDir, outputPolicyFile):
 
     for action_elem in tree.iter("action"):
         action = Action(action_elem)
-        for lang in tr_dict:
+        for lang in sorted(tr_dict):
             d = tr_dict[lang]
             src = ""
             for ty in ["description", "message"]:
